==> huaweicloudsdkcdn-3.1.65-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/range_status_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RangeStatusRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'range_status': 'str'
    }

    attribute_map = {
        'range_status': 'range_status'
    }

    def __init__(self, range_status=None):
        """RangeStatusRequest

        The model defined in huaweicloud sdk

        :param range_status: range状态（\&quot;off\&quot;/\&quot;on\&quot;）
        :type range_status: str
        """
        
        

        self._range_status = None
        self.discriminator = None

        self.range_status = range_status

    @property
    def range_status(self):
        """Gets the range_status of this RangeStatusRequest.

        range状态（\"off\"/\"on\"）

        :return: The range_status of this RangeStatusRequest.
        :rtype: str
        """
        return self._range_status

    @range_status.setter
    def range_status(self, range_status):
        """Sets the range_status of this RangeStatusRequest.

        range状态（\"off\"/\"on\"）

        :param range_status: The range_status of this RangeStatusRequest.
        :type range_status: str
        """
        self._range_status = range_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RangeStatusRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.1.158-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/range_status_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RangeStatusRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'range_status': 'str'
    }

    attribute_map = {
        'range_status': 'range_status'
    }

    def __init__(self, range_status=None):
        r"""RangeStatusRequest

        The model defined in huaweicloud sdk

        :param range_status: range状态（\&quot;off\&quot;/\&quot;on\&quot;）
        :type range_status: str
        """
        
        

        self._range_status = None
        self.discriminator = None

        self.range_status = range_status

    @property
    def range_status(self):
        r"""Gets the range_status of this RangeStatusRequest.

        range状态（\"off\"/\"on\"）

        :return: The range_status of this RangeStatusRequest.
        :rtype: str
        """
        return self._range_status

    @range_status.setter
    def range_status(self, range_status):
        r"""Sets the range_status of this RangeStatusRequest.

        range状态（\"off\"/\"on\"）

        :param range_status: The range_status of this RangeStatusRequest.
        :type range_status: str
        """
        self._range_status = range_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RangeStatusRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
